{
    description = "Project Tool";

    inputs = {
        nixpkgs.url = "github:NixOS/nixpkgs/nixpkgs-unstable";
        flake-utils.url = "github:numtide/flake-utils";
        rust-overlay = {
            url = "github:oxalica/rust-overlay";
            inputs.nixpkgs.follows = "nixpkgs";
        };
    };

    outputs = { nixpkgs, flake-utils, rust-overlay, ... }:
        flake-utils.lib.eachDefaultSystem (system:
            let
                overlays = [ (import rust-overlay) ];
                pkgs = import nixpkgs { inherit system overlays; };
                rust = pkgs.rust-bin;

                rustToolchain = rust.fromRustupToolchainFile ./rust-toolchain.toml;
                rustNightlyToolchain = rust.selectLatestNightlyWith (t: t.minimal.override {
                    extensions = [ "rustfmt" ];
                });

                buildTools = [
                    rustToolchain
                    rustNightlyToolchain
                ];
            in {
                devShells.default = pkgs.mkShell {
                    name = "projtool";

                    nativeBuildInputs = buildTools;
                };
            });
}
