mod cli;
mod dirs;
mod state;
mod tui;


use std::path::PathBuf;

use anyhow::Result;
use clap::Parser;
use cli::Command;
use state::read_projects_file;


#[derive(Debug, Parser)]
struct Args {
    #[command(subcommand)]
    pub cmd: Option<Command>,
}


#[derive(Debug, Default, serde::Serialize, serde::Deserialize)]
struct Projects {
    pub list: Vec<PathBuf>,
}


fn main() -> Result<()> {
    let args = Args::parse();

    let projects = read_projects_file()?;

    match &args.cmd {
        Some(cmd) => cmd.execute(projects)?,
        None => tui::run(projects)?,
    };

    Ok(())
}
